@@ -13,26 +13,42 @@ from ply import lex, yacc
 from kodexa.selectors import lexrules
 from kodexa.selectors import parserules
 
-__all__ = ['lexer', 'parser', 'parse']
+__all__ = ["lexer", "parser", "parse"]
 
-OPERATOR_FORCERS = {'PIPELINE_OP', 'ABBREV_AXIS_AT', 'AXIS_SEP', 'OPEN_PAREN', 'OPEN_BRACKET', 'AND_OP', 'OR_OP',
-                    'MOD_OP', 'DIV_OP',
-                    'MULT_OP', 'PATH_SEP', 'ABBREV_PATH_SEP', 'UNION_OP', 'PLUS_OP', 'MINUS_OP', 'EQUAL_OP', 'REL_OP',
-                    'COLON'}
+OPERATOR_FORCERS = {
+    "PIPELINE_OP",
+    "ABBREV_AXIS_AT",
+    "AXIS_SEP",
+    "OPEN_PAREN",
+    "OPEN_BRACKET",
+    "AND_OP",
+    "OR_OP",
+    "MOD_OP",
+    "DIV_OP",
+    "MULT_OP",
+    "PATH_SEP",
+    "ABBREV_PATH_SEP",
+    "UNION_OP",
+    "PLUS_OP",
+    "MINUS_OP",
+    "EQUAL_OP",
+    "REL_OP",
+    "COLON",
+}
 
-NODE_TYPES = {'comment', 'text', 'processing-instruction', 'node'}
+NODE_TYPES = {"comment", "text", "processing-instruction", "node"}
 
 
 class LexerWrapper(lex.Lexer):
     def token(self):
         tok = lex.Lexer.token(self)
         if tok is not None:
-            if tok.type == 'STAR_OP':
+            if tok.type == "STAR_OP":
                 if self.last is not None and self.last.type not in OPERATOR_FORCERS:
                     # first half of point 1
-                    tok.type = 'MULT_OP'
+                    tok.type = "MULT_OP"
 
-            if tok.type == 'NCNAME':
+            if tok.type == "NCNAME":
                 if self.last is not None and self.last.type not in OPERATOR_FORCERS:
                     # second half of point 1
                     operator = lexrules.operator_names.get(tok.value, None)
@@ -41,15 +57,15 @@ class LexerWrapper(lex.Lexer):
                 else:
                     self_next = self.peek()
                     if self_next is not None:
-                        if self_next.type == 'OPEN_PAREN':
+                        if self_next.type == "OPEN_PAREN":
                             # point 2
                             if tok.value in NODE_TYPES:
-                                tok.type = 'NODETYPE'
+                                tok.type = "NODETYPE"
                             else:
-                                tok.type = 'FUNCNAME'
-                        elif self_next.type == 'AXIS_SEP':
+                                tok.type = "FUNCNAME"
+                        elif self_next.type == "AXIS_SEP":
                             # point 3
-                            tok.type = 'AXISNAME'
+                            tok.type = "AXISNAME"
 
         self.last = tok
         return tok
@@ -65,8 +81,7 @@ class LexerWrapper(lex.Lexer):
 lexdir = os.path.dirname(lexrules.__file__)
 lexer = None
 try:
-    lexer = lex.lex(module=lexrules, optimize=1, outputdir=lexdir,
-                    reflags=re.UNICODE)
+    lexer = lex.lex(module=lexrules, optimize=1, outputdir=lexdir, reflags=re.UNICODE)
 except IOError as e:
     import errno
 
@@ -86,13 +101,13 @@ lexer.last = None
 parsedir = os.path.dirname(parserules.__file__)
 # By default, store generated parse files with the code
 # If we don't have write permission, put them in the configured tempdir
-if (not os.access(parsedir, os.W_OK)):
+if not os.access(parsedir, os.W_OK):
     parsedir = tempfile.gettempdir()
 parser = yacc.yacc(module=parserules, outputdir=parsedir, debug=0)
 
 
 def parse(xpath):
-    '''Parse an xpath.'''
+    """Parse an xpath."""
     # Expose the parse method of the constructed parser,
     # but explicitly specify the lexer created here,
     # since otherwise parse will use the most-recently created lexer.
@@ -100,9 +115,9 @@ def parse(xpath):
 
 
 def ptokens(s):
-    '''Lex a string as XPath tokens, and print each token as it is lexed.
+    """Lex a string as XPath tokens, and print each token as it is lexed.
     This is used primarily for debugging. You probably don't want this
-    function.'''
+    function."""
 
     lexer.input(s)
     for tok in lexer:
